@@ -15,6 +15,7 @@ from .const import (
     SPECIAL_TIMES,
     TEMP_MINIMUM,
     TEMP_OFF,
+    TEXT_ALL,
     TEXT_DEGREESC,
     TEXT_HEATING,
     TEXT_LEVEL,
@@ -139,9 +140,12 @@ class _WiserSchedule(object):
                         if day.title() == TEXT_WEEKDAYS:
                             for weekday in WEEKDAYS:
                                 schedule_output.update({weekday: schedule_day})
-                        if day.title() == TEXT_WEEKENDS:
+                        elif day.title() == TEXT_WEEKENDS:
                             for weekend_day in WEEKENDS:
                                 schedule_output.update({weekend_day: schedule_day})
+                        elif day.title() == TEXT_ALL:
+                            for day in WEEKDAYS + WEEKENDS:
+                                schedule_output.update({day: schedule_day})
                     else:
                         schedule_output.update({day: schedule_day})
             return schedule_output
@@ -322,7 +326,7 @@ class _WiserSchedule(object):
             )
             return True
         except Exception as ex:
-            _LOGGER.error(f"Error copying schedule: {ex}")
+            _LOGGER.error(f"Error setting schedule: {ex}")
             return False
 
     async def set_schedule_from_file(self, schedule_file: str) -> bool:
@@ -353,6 +357,26 @@ class _WiserSchedule(object):
             _LOGGER.error(f"Error setting schedule from file: {ex}")
             return False
 
+    async def set_schedule_from_yaml_data(self, schedule_data: str) -> bool:
+        """
+        Set new schedule
+        param scheduleData: json data respresenting a schedule
+        return: boolen - true = successfully set, false = failed to set
+        """
+        try:
+            schedule_data = yaml.load(schedule_data, SafeLoader)
+            if self._validate_schedule_type(schedule_data):
+                    schedule = self._convert_to_wiser_schedule(schedule_data)
+                    await self.set_schedule(schedule)
+                    return True
+            else:
+                _LOGGER.error(
+                    f"This is an incorrect schedule type for this device.  It should be a {self.schedule_type} schedule."
+                )
+        except Exception as ex:
+            _LOGGER.error(f"Error setting schedule from yaml data: {ex}")
+            return False
+
     async def set_schedule_from_yaml_file(self, schedule_yaml_file: str) -> bool:
         """
         Set schedule from file.
@@ -992,13 +1016,18 @@ class _WiserScheduleCollection(object):
 
     def get_by_name(
         self, schedule_type: WiserScheduleTypeEnum, name: str
-    ) -> _WiserSchedule:
+    ) :
         """
         Gets a schedule object from the schedules name
         (room name, smart plug name, hotwater)
         param name: name of schedule
         return: _WiserSchedule object
         """
+        if schedule_type in [
+            WiserScheduleTypeEnum.lighting,
+            WiserScheduleTypeEnum.shutters,
+        ]:
+            schedule_type = WiserScheduleTypeEnum.level
         try:
             if schedule_type == WiserScheduleTypeEnum.level:
                 return [
@@ -1009,7 +1038,7 @@ class _WiserScheduleCollection(object):
             return [
                 schedule
                 for schedule in self.all
-                if schedule.schedule_type == schedule_type and schedule.name == name
+                if schedule.schedule_type == schedule_type.value and schedule.name == name
             ][0]
         except IndexError:
             return None
